package com.yijia.station.service.impl;

import java.util.List;
import java.util.Map;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.yijia.station.mapper.StationDeviceManageMapper;
import com.yijia.station.domain.StationDeviceManage;
import com.yijia.station.service.IStationDeviceManageService;

/**
 * 油站设备管理Service业务层处理
 * 
 * @author yijia
 * @date 2021-01-13
 */
@Service
public class StationDeviceManageServiceImpl implements IStationDeviceManageService 
{
    @Autowired
    private StationDeviceManageMapper stationDeviceManageMapper;

    /**
     * 查询油站设备管理
     * 
     * @param deviceId 油站设备管理ID
     * @return 油站设备管理
     */
    @Override
    public StationDeviceManage selectStationDeviceManageById(Long deviceId)
    {
        return stationDeviceManageMapper.selectStationDeviceManageById(deviceId);
    }

    /**
     * 查询油站设备管理列表
     * 
     * @param stationDeviceManage 油站设备管理
     * @return 油站设备管理
     */
    @Override
    public List<StationDeviceManage> selectStationDeviceManageList(StationDeviceManage stationDeviceManage)
    {
        return stationDeviceManageMapper.selectStationDeviceManageList(stationDeviceManage);
    }

    /**
     * 新增油站设备管理
     * 
     * @param stationDeviceManage 油站设备管理
     * @return 结果
     */
    @Override
    public int insertStationDeviceManage(StationDeviceManage stationDeviceManage)
    {
        return stationDeviceManageMapper.insertStationDeviceManage(stationDeviceManage);
    }

    /**
     * 修改油站设备管理
     * 
     * @param stationDeviceManage 油站设备管理
     * @return 结果
     */
    @Override
    public int updateStationDeviceManage(StationDeviceManage stationDeviceManage)
    {
        return stationDeviceManageMapper.updateStationDeviceManage(stationDeviceManage);
    }

    /**
     * 批量删除油站设备管理
     * 
     * @param deviceIds 需要删除的油站设备管理ID
     * @return 结果
     */
    @Override
    public int deleteStationDeviceManageByIds(Long[] deviceIds)
    {
        return stationDeviceManageMapper.deleteStationDeviceManageByIds(deviceIds);
    }

    /**
     * 删除油站设备管理信息
     * 
     * @param deviceId 油站设备管理ID
     * @return 结果
     */
    @Override
    public int deleteStationDeviceManageById(Long deviceId)
    {
        return stationDeviceManageMapper.deleteStationDeviceManageById(deviceId);
    }

    @Override
    public Map<String, Object> getPrinterSnByStationId(Map<String, Object> params) {
        return stationDeviceManageMapper.getPrinterSnByStationId(params);
    }
}
